@@ -21,15 +21,16 @@
 
 #include <cmath>
 
-namespace KDecoration2
-{
 #ifndef K_DOXYGEN
-uint qHash(const DecorationButtonType &type)
+size_t qHash(const KDecoration2::DecorationButtonType &type, size_t seed)
 {
-    return static_cast<uint>(type);
+    return qHash(uint(type), seed);
 }
 #endif
 
+namespace KDecoration2
+{
+
 DecorationButton::Private::Private(DecorationButtonType type, const QPointer<Decoration> &decoration, DecorationButton *parent)
     : decoration(decoration)
     , type(type)
