@@ -64,25 +64,29 @@ void DecorationButtonGroup::Private::updateLayout()
     qreal leftPosition = pos.x();
     qreal rightPosition = pos.x() + width;
 
-    if (layoutDirection == Qt::LeftToRight) for (auto button : qAsConst(buttons)) {
-        if (!button->isVisible()) {
-            continue;
+    if (layoutDirection == Qt::LeftToRight)
+        for (auto button : std::as_const(buttons)) {
+            if (!button->isVisible()) {
+                continue;
+            }
+            const auto size = button->size();
+            const auto buttonPos = QPointF(leftPosition, pos.y());
+            button->setGeometry(QRectF(buttonPos, size));
+            leftPosition += size.width() + spacing;
         }
-        const auto size = button->size();
-        const auto buttonPos = QPointF(leftPosition, pos.y());
-        button->setGeometry(QRectF(buttonPos, size));
-        leftPosition += size.width() + spacing;
-    } else if (layoutDirection == Qt::RightToLeft) for (auto button : qAsConst(buttons)) {
-        if (!button->isVisible()) {
-            continue;
+    else if (layoutDirection == Qt::RightToLeft)
+        for (auto button : std::as_const(buttons)) {
+            if (!button->isVisible()) {
+                continue;
+            }
+            const auto size = button->size();
+            const auto buttonPos = QPointF(rightPosition - size.width(), pos.y());
+            button->setGeometry(QRectF(buttonPos, size));
+            rightPosition -= size.width() + spacing;
         }
-        const auto size = button->size();
-        const auto buttonPos = QPointF(rightPosition - size.width(), pos.y());
-        button->setGeometry(QRectF(buttonPos, size));
-        rightPosition -= size.width() + spacing;
-    } else {
-    	qCritical() << "There's an unhandled layout direction! This is likely an issue of KDecoration2 not being updated to handle it\n"
-    	            << "or the application having an invalid layout direction set. Either way, this is a critical bug.";
+    else {
+        qCritical() << "There's an unhandled layout direction! This is likely an issue of KDecoration2 not being updated to handle it\n"
+                    << "or the application having an invalid layout direction set. Either way, this is a critical bug.";
     }
 
     s_layoutRecursion = false;
@@ -110,13 +114,13 @@ DecorationButtonGroup::DecorationButtonGroup(DecorationButtonGroup::Position typ
                 (layoutDirection == Qt::LeftToRight ? settings->decorationButtonsRight() : settings->decorationButtonsLeft());
         for (DecorationButtonType type : buttons) {
             if (DecorationButton *b = buttonCreator(type, parent, this)) {
-                addButton(QPointer<DecorationButton>(b));
+                addButton(b);
             }
         }
     };
     createButtons();
     auto changed = type == Position::Left ? &DecorationSettings::decorationButtonsLeftChanged : &DecorationSettings::decorationButtonsRightChanged;
-    connect(settings.data(), changed, this, [this, createButtons] {
+    connect(settings.get(), changed, this, [this, createButtons] {
         qDeleteAll(d->buttons);
         d->buttons.clear();
         createButtons();
@@ -125,9 +129,9 @@ DecorationButtonGroup::DecorationButtonGroup(DecorationButtonGroup::Position typ
 
 DecorationButtonGroup::~DecorationButtonGroup() = default;
 
-QPointer<Decoration> DecorationButtonGroup::decoration() const
+Decoration *DecorationButtonGroup::decoration() const
 {
-    return QPointer<Decoration>(d->decoration);
+    return d->decoration;
 }
 
 QRectF DecorationButtonGroup::geometry() const
@@ -138,7 +142,7 @@ QRectF DecorationButtonGroup::geometry() const
 bool DecorationButtonGroup::hasButton(DecorationButtonType type) const
 {
     // TODO: check for deletion of button
-    auto it = std::find_if(d->buttons.begin(), d->buttons.end(), [type](const QPointer<DecorationButton> &button) {
+    auto it = std::find_if(d->buttons.begin(), d->buttons.end(), [type](DecorationButton *button) {
         return button->type() == type;
     });
     return it != d->buttons.end();
@@ -173,20 +177,20 @@ void DecorationButtonGroup::setSpacing(qreal spacing)
     d->updateLayout();
 }
 
-void DecorationButtonGroup::addButton(const QPointer<DecorationButton> &button)
+void DecorationButtonGroup::addButton(DecorationButton *button)
 {
-    Q_ASSERT(!button.isNull());
-    connect(button.data(), &DecorationButton::visibilityChanged, this, [this]() {
+    Q_ASSERT(button);
+    connect(button, &DecorationButton::visibilityChanged, this, [this]() {
         d->updateLayout();
     });
-    connect(button.data(), &DecorationButton::geometryChanged, this, [this]() {
+    connect(button, &DecorationButton::geometryChanged, this, [this]() {
         d->updateLayout();
     });
     d->buttons.append(button);
     d->updateLayout();
 }
 
-QVector<QPointer<DecorationButton>> DecorationButtonGroup::buttons() const
+QList<DecorationButton *> DecorationButtonGroup::buttons() const
 {
     return d->buttons;
 }
@@ -208,7 +212,7 @@ void DecorationButtonGroup::removeButton(DecorationButtonType type)
     }
 }
 
-void DecorationButtonGroup::removeButton(const QPointer<DecorationButton> &button)
+void DecorationButtonGroup::removeButton(DecorationButton *button)
 {
     bool needUpdate = false;
     auto it = d->buttons.begin();
@@ -237,3 +241,5 @@ void DecorationButtonGroup::paint(QPainter *painter, const QRect &repaintArea)
 }
 
 } // namespace
+
+#include "moc_decorationbuttongroup.cpp"
